import React, { useEffect, useState } from 'react';
import { Input, Modal } from 'antd';
import styles from './styles.less';
import { antiAssign } from '../../../../utils/utils';
import { ApolloTextAreaProps } from '../editInterface';
import { Consumer } from '../../../context';

export const ApolloTextLink = (props: ApolloTextAreaProps) => {
    const { maxLength, onChange, value, cutLength, getDetail, rowData, onEmitChange, columnConfig, origin } = props;
    const { columnChsName } = columnConfig;
    const selfProps = antiAssign(props, ['columnConfig', 'onChange', 'value', 'cutLength', 'getDetail', 'rowData', 'onEmitChange']);
    const [curValue, setCurValue] = useState(value);
    const [visible, setVisible] = useState(false);
    useEffect(() => {
        if (origin !== 'editForm') {
            setCurValue(value);
            getMore();
        }
    }, [value]);
    // useEffect(() => {
    //     if (value && value.length === cutLength) {
    //         getMore();
    //     }
    // }, []);

    const changeValue = (e) => {
        if (typeof onChange === 'function') {
            onChange(e.target.value);
        }
    };

    const changeCurValue = (e) => {
        if (typeof onChange === 'function') {
            setCurValue(e.target.value);
        }
    };

    const hide = () => {
        if (typeof onEmitChange === 'function') {
            onEmitChange(value);
        }
        setVisible(false);
    }

    const confirmChange = () => {
        if (typeof onEmitChange === 'function') {
            onEmitChange(curValue);
        }
        setVisible(false);
    }

    const getMore = async () => {
        setVisible(true);
    };

    if (origin === 'editForm') {
        return (
            <Consumer>
                {({ locale }) => {
                    return (
                        <div className={styles.container}>
                            <Input.TextArea
                                className={styles.inputForm}
                                {...selfProps}
                                value={value}
                                onChange={changeValue}
                            />
                            {!!maxLength && (
                                <span className={styles.wordNumberForm}>
                                    {`${locale.alreadyInput} ${(value || '').length}/${maxLength}`}
                                </span>
                            )}
                        </div>
                    );
                }}
            </Consumer>
        )
    }

    return (
        <Consumer>
            {({ locale }) => {
                return (
                    <div className={styles.container}>
                        <Input
                            {...selfProps}
                            value={value}
                            onChange={changeValue}
                        />
                        <Modal visible={visible} title={columnChsName} onCancel={hide} onOk={confirmChange}>
                            <Input.TextArea
                                className={styles.input}
                                {...selfProps}
                                value={curValue}
                                onChange={changeCurValue}
                            />
                            {!!maxLength && (
                                <span className={styles.wordNumber}>
                                    {`${locale.alreadyInput} ${(curValue || '').length}/${maxLength}`}
                                </span>
                            )}
                        </Modal>
                    </div>
                );
            }}
        </Consumer>
    );
};
